@@ -593,34 +593,34 @@ function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || func
 
 function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
 
-var PerfectScrollbar = /*#__PURE__*/function (_HTMLElement) {
-  _inherits(PerfectScrollbar, _HTMLElement);
+var PerfectScrollbarEl = /*#__PURE__*/function (_HTMLElement) {
+  _inherits(PerfectScrollbarEl, _HTMLElement);
 
-  var _super = _createSuper(PerfectScrollbar);
+  var _super = _createSuper(PerfectScrollbarEl);
 
-  function PerfectScrollbar() {
-    _classCallCheck(this, PerfectScrollbar);
+  function PerfectScrollbarEl() {
+    _classCallCheck(this, PerfectScrollbarEl);
 
     return _super.call(this);
   }
 
-  _createClass(PerfectScrollbar, [{
+  _createClass(PerfectScrollbarEl, [{
     key: "connectedCallback",
     value: function connectedCallback() {
-      $(this).parent().perfectScrollbar();
+      this.scrollbar = new PerfectScrollbar($(this).parent().get(0));
     }
   }, {
     key: "disconnectedCallback",
     value: function disconnectedCallback() {
-      $(this).parent().perfectScrollbar('destroy');
+      this.scrollbar.destroy();
     }
   }]);
 
-  return PerfectScrollbar;
+  return PerfectScrollbarEl;
 }( /*#__PURE__*/_wrapNativeSuper(HTMLElement));
 
 window.addEventListener('load', function () {
-  window.customElements.define('dmc-scrollbar', PerfectScrollbar);
+  window.customElements.define('dmc-scrollbar', PerfectScrollbarEl);
 });
 "use strict";
 
@@ -736,13 +736,13 @@ var Sidenav = /*#__PURE__*/function (_HTMLElement) {
 
       $(this).find('.sidenav').sidenav();
       $(document).activeNavigation('#slide-out');
-      $('#slide-out').perfectScrollbar();
+      this.scrollbar = new PerfectScrollbar($('#slide-out').get(0));
     }
   }, {
     key: "disconnectedCallback",
     value: function disconnectedCallback() {
       $(this).find('.sidenav').sidenav('destroy');
-      $('#slide-out').perfectScrollbar('destroy');
+      this.scrollbar.destroy();
     }
   }]);
 
